gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-merchant] branch master updated: fix spelling mistakes


From: gnunet
Subject: [taler-merchant] branch master updated: fix spelling mistakes
Date: Sat, 25 Jul 2020 03:56:37 +0200

This is an automated email from the git hooks/post-receive script.

jonathan-buchanan pushed a commit to branch master
in repository merchant.

The following commit(s) were added to refs/heads/master by this push:
     new 469ea4f  fix spelling mistakes
469ea4f is described below

commit 469ea4f5c7a23ac89965bca8139e17d7bd26b9f0
Author: Jonathan Buchanan <jonathan.russ.buchanan@gmail.com>
AuthorDate: Fri Jul 24 21:56:08 2020 -0400

    fix spelling mistakes
---
 contrib/uncrustify-mode.el                   |  2 +-
 contrib/uncrustify_precommit                 |  2 +-
 m4/ax_lib_postgresql.m4                      |  2 +-
 src/backend/taler-merchant-httpd.c           | 12 ++++++------
 src/backend/taler-merchant-httpd.h           |  4 ++--
 src/backend/taler-merchant-httpd_exchanges.c |  2 +-
 src/backend/taler-merchant-httpd_reserves.c  |  2 +-
 src/backenddb/merchant-0001.sql              |  2 +-
 src/backenddb/plugin_merchantdb_postgres.c   |  2 +-
 src/backenddb/test_merchantdb.c              | 12 ++++++------
 src/include/taler_merchant_service.h         |  2 +-
 src/lib/merchant_api_get_transfers.c         |  2 +-
 12 files changed, 23 insertions(+), 23 deletions(-)

diff --git a/contrib/uncrustify-mode.el b/contrib/uncrustify-mode.el
index 83868c6..cf615b0 100755
--- a/contrib/uncrustify-mode.el
+++ b/contrib/uncrustify-mode.el
@@ -114,7 +114,7 @@
                               (message "uncrustify error: <%s> <%s>" ret 
(buffer-string)))
                             nil))))))
 
-          ;; This goto-line is outside the save-excursion becuase it'd get
+          ;; This goto-line is outside the save-excursion because it'd get
           ;; removed otherwise.  I hate this bug. It makes things so ugly.
           (goto-line original-line)
           (not result)))
diff --git a/contrib/uncrustify_precommit b/contrib/uncrustify_precommit
index fd29998..2487333 100755
--- a/contrib/uncrustify_precommit
+++ b/contrib/uncrustify_precommit
@@ -30,6 +30,6 @@ if [ $RET = 1 ];
 then
   echo "Run"
   echo "uncrustify --no-backup -c uncrustify.cfg ${crustified}"
-  echo "before commiting."
+  echo "before committing."
 fi
 exit $RET
diff --git a/m4/ax_lib_postgresql.m4 b/m4/ax_lib_postgresql.m4
index 11b6991..9eb4316 100644
--- a/m4/ax_lib_postgresql.m4
+++ b/m4/ax_lib_postgresql.m4
@@ -80,7 +80,7 @@ AC_DEFUN([AX_LIB_POSTGRESQL],
         fi
 
         if test ! -x "$PG_CONFIG"; then
-            dnl AC_MSG_ERROR([$PG_CONFIG does not exist or it is not an 
exectuable file])
+            dnl AC_MSG_ERROR([$PG_CONFIG does not exist or it is not an 
executable file])
             PG_CONFIG="no"
             found_postgresql="no"
         fi
diff --git a/src/backend/taler-merchant-httpd.c 
b/src/backend/taler-merchant-httpd.c
index b6cb1cc..75a4cf4 100644
--- a/src/backend/taler-merchant-httpd.c
+++ b/src/backend/taler-merchant-httpd.c
@@ -1115,7 +1115,7 @@ url_handler (void *cls,
       {
         /* Client exceeds upload limit. Should _usually_ be checked earlier
            when we look at the MHD_HTTP_HEADER_CONTENT_LENGTH, alas with
-           chunked encoding an uploader MAY have ommitted this, and thus
+           chunked encoding an uploader MAY have omitted this, and thus
            not permitted us to check on time. In this case, we just close
            the connection once it exceeds our limit (instead of waiting
            for the upload to complete and then fail). This could theoretically
@@ -1299,28 +1299,28 @@ url_handler (void *cls,
             continue; /* too many segments to match */
           if ( (NULL == infix_url)
                ^ (NULL == rh->url_suffix) )
-            continue; /* suffix existence missmatch */
+            continue; /* suffix existence mismatch */
           if ( (NULL != infix_url) &&
                ( (infix_strlen != strlen (rh->url_suffix)) ||
                  (0 != memcmp (infix_url,
                                rh->url_suffix,
                                infix_strlen)) ) )
-            continue; /* cannot use infix as suffix: content missmatch */
+            continue; /* cannot use infix as suffix: content mismatch */
         }
         else
         {
           if ( (NULL == infix_url)
                ^ (GNUNET_NO == rh->have_id_segment) )
-            continue; /* infix existence missmatch */
+            continue; /* infix existence mismatch */
           if ( ( (NULL == suffix_url)
                  ^ (NULL == rh->url_suffix) ) )
-            continue; /* suffix existence missmatch */
+            continue; /* suffix existence mismatch */
           if ( (NULL != suffix_url) &&
                ( (suffix_strlen != strlen (rh->url_suffix)) ||
                  (0 != memcmp (suffix_url,
                                rh->url_suffix,
                                suffix_strlen)) ) )
-            continue; /* suffix content missmatch */
+            continue; /* suffix content mismatch */
         }
         url_found = true;
         if (0 == strcasecmp (method,
diff --git a/src/backend/taler-merchant-httpd.h 
b/src/backend/taler-merchant-httpd.h
index f4c1b64..8ee900b 100644
--- a/src/backend/taler-merchant-httpd.h
+++ b/src/backend/taler-merchant-httpd.h
@@ -148,7 +148,7 @@ struct TMH_RequestHandler;
 /**
  * This information is stored in the "connection_cls" of MHD for
  * every request that we process.
- * Individual handlers can evaluate tis memebers and
+ * Individual handlers can evaluate its members and
  * are allowed to update @e cc and @e ctx to store and clean up
  * handler-specific data.
  */
@@ -253,7 +253,7 @@ typedef void
 /**
  * This information is stored in the "connection_cls" of MHD for
  * every request that we process.
- * Individual handlers can evaluate tis memebers and
+ * Individual handlers can evaluate its members and
  * are allowed to update @e cc and @e ctx to store and clean up
  * handler-specific data.
  */
diff --git a/src/backend/taler-merchant-httpd_exchanges.c 
b/src/backend/taler-merchant-httpd_exchanges.c
index c31ce46..721c10e 100644
--- a/src/backend/taler-merchant-httpd_exchanges.c
+++ b/src/backend/taler-merchant-httpd_exchanges.c
@@ -1034,7 +1034,7 @@ TMH_EXCHANGES_find_exchange (const char *chosen_exchange,
     /* increment exponential-backoff */
     exchange->retry_delay = RETRY_BACKOFF (exchange->retry_delay);
     /* do not allow forced check until both backoff and #FORCED_RELOAD_DELAY
-       are satisified again */
+       are satisfied again */
     exchange->first_retry
       = GNUNET_TIME_relative_to_absolute (GNUNET_TIME_relative_max (
                                             exchange->retry_delay,
diff --git a/src/backend/taler-merchant-httpd_reserves.c 
b/src/backend/taler-merchant-httpd_reserves.c
index 172b6f9..1a2e1aa 100644
--- a/src/backend/taler-merchant-httpd_reserves.c
+++ b/src/backend/taler-merchant-httpd_reserves.c
@@ -48,7 +48,7 @@ struct Reserve
 
   /**
    * Amount the merchant expects to see in the reserve initially.
-   * We log a warning if there is a missmatch.
+   * We log a warning if there is a mismatch.
    */
   struct TALER_Amount expected_amount;
 
diff --git a/src/backenddb/merchant-0001.sql b/src/backenddb/merchant-0001.sql
index e55ea02..f26cd5a 100644
--- a/src/backenddb/merchant-0001.sql
+++ b/src/backenddb/merchant-0001.sql
@@ -150,7 +150,7 @@ COMMENT ON COLUMN merchant_inventory.taxes
 COMMENT ON COLUMN merchant_inventory.price_val
   IS 'Current price of one unit of the product';
 COMMENT ON COLUMN merchant_inventory.total_stock
-  IS 'A value of -1 is used for unlimited (eletronic good), may never be 
lowered';
+  IS 'A value of -1 is used for unlimited (electronic good), may never be 
lowered';
 COMMENT ON COLUMN merchant_inventory.total_sold
   IS 'Number of products sold, must be below total_stock, non-negative, may 
never be lowered';
 COMMENT ON COLUMN merchant_inventory.total_lost
diff --git a/src/backenddb/plugin_merchantdb_postgres.c 
b/src/backenddb/plugin_merchantdb_postgres.c
index 8d4db04..84e1bce 100644
--- a/src/backenddb/plugin_merchantdb_postgres.c
+++ b/src/backenddb/plugin_merchantdb_postgres.c
@@ -4441,7 +4441,7 @@ struct LookupReservesContext
   enum TALER_EXCHANGE_YesNoAll active;
 
   /**
-   * Filter by failures (missmatch in exchange claimed and
+   * Filter by failures (mismatch in exchange claimed and
    * merchant claimed initial amounts).
    */
   enum TALER_EXCHANGE_YesNoAll failures;
diff --git a/src/include/taler_merchant_service.h 
b/src/include/taler_merchant_service.h
index 9a7ceb3..189d314 100644
--- a/src/include/taler_merchant_service.h
+++ b/src/include/taler_merchant_service.h
@@ -2482,7 +2482,7 @@ typedef void
  *                 #GNUNET_TIME_UNIT_FOREVER_ABS to not filter by @a before
  * @param after limit to transactions after this timestamp, use
  *                 #GNUNET_TIME_UNIT_ZERO_ABS to not filter by @a after
- * @param limit return at most ths number of results; negative to descend in 
execution time
+ * @param limit return at most this number of results; negative to descend in 
execution time
  * @param offset start at this "credit serial" number (exclusive)
  * @param verified filter results by verification status
  * @param cb the callback to call when a reply for this request is available
diff --git a/src/lib/merchant_api_get_transfers.c 
b/src/lib/merchant_api_get_transfers.c
index 34d043f..fe1d14b 100644
--- a/src/lib/merchant_api_get_transfers.c
+++ b/src/lib/merchant_api_get_transfers.c
@@ -236,7 +236,7 @@ handle_transfers_get_finished (void *cls,
  *                 #GNUNET_TIME_UNIT_FOREVER_ABS to not filter by @a before
  * @param after limit to transactions after this timestamp, use
  *                 #GNUNET_TIME_UNIT_ZERO_ABS to not filter by @a after
- * @param limit return at most ths number of results; negative to descend in 
execution time
+ * @param limit return at most this number of results; negative to descend in 
execution time
  * @param offset start at this "credit serial" number (exclusive)
  * @param verified filter results by verification status
  * @param cb the callback to call when a reply for this request is available

diff --git a/src/backenddb/test_merchantdb.c b/src/backenddb/test_merchantdb.c
index 81f66b2..12391d1 100644
--- a/src/backenddb/test_merchantdb.c
+++ b/src/backenddb/test_merchantdb.c
@@ -467,7 +467,7 @@ test_insert_account (const struct InstanceData *instance,
 /**
  * Tests deactivating an account.
  *
  * @param account the account to inactivate.
  * @param expected_result the result expected from the plugin.
  * @return 0 on success, 1 otherwise.
  */
@@ -478,7 +478,7 @@ test_inactivate_account (const struct 
TALER_MERCHANTDB_AccountDetails *account,
   TEST_COND_RET_ON_FAIL (expected_result ==
                          plugin->inactivate_account (plugin->cls,
                                                      &account->h_wire),
-                         "Inactivate account failed\n");
+                         "Deactivate account failed\n");
   return 0;
 }
 
@@ -611,7 +611,7 @@ run_test_instances (struct TestInstances_Closure *cls)
   TEST_RET_ON_FAIL (test_lookup_instances (false,
                                            1,
                                            instances));
   /* Test inactivate account */
   TEST_RET_ON_FAIL (test_inactivate_account (&cls->accounts[0],
                                              
GNUNET_DB_STATUS_SUCCESS_ONE_RESULT));
   TEST_RET_ON_FAIL (test_inactivate_account (&cls->accounts[1],
@@ -2918,7 +2918,7 @@ get_deposit_serial_cb (void *cls,
 
 
 /**
- * Convenience function to retrive the row number of a deposit in the database.
+ * Convenience function to retrieve the row number of a deposit in the 
database.
  *
  * @param instance the instance to get deposits from.
  * @param order the order associated with the deposit.
@@ -3648,7 +3648,7 @@ struct TestLookupTransferDetailsByOrder_Closure
  * @param cls pointer to 'TestLookupTransferDetailsByOrder_Closure'.
  * @param wtid identifier of the transfer found.
  * @param exchange_url exchange url of the transfer found.
- * @param execution_time when the transfer found occured.
+ * @param execution_time when the transfer found occurred.
  * @param deposit_value amount of the deposit for the transfer found.
  * @param deposit_fee amount of the fee for the deposit of the transfer.
  * @param transfer_confirmed whether the transfer was confirmed.
@@ -5684,7 +5684,7 @@ test_lookup_refunds (const struct InstanceData *instance,
 struct RefundData
 {
   /**
-   * When the refund occured.
+   * When the refund occurred.
    */
   struct GNUNET_TIME_Absolute timestamp;
 
@@ -467,7 +467,7 @@ test_insert_account (const struct InstanceData *instance,
  * Tests deactivating an account.
  *
- * @param account the account to inactivate.
+ * @param account the account to deactivate.
  * @param expected_result the result expected from the plugin.
  * @return 0 on success, 1 otherwise.
@@ -611,7 +611,7 @@ run_test_instances (struct TestInstances_Closure *cls)
                                            1,
                                            instances));
-  /* Test inactivate account */
+  /* Test deactivate account */
   TEST_RET_ON_FAIL (test_inactivate_account (&cls->accounts[0],
                                              
-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]